@@ -1,5 +1,6 @@
 # -*- coding: future_annotations -*-
 import ast
+import builtins
 from collections import defaultdict
 from enum import Enum
 import logging
@@ -11,10 +12,13 @@ try:
 except ImportError:
     numpy = None
 
-from nbsafety.data_model.annotation_utils import get_type_annotation, make_annotation_string
 from nbsafety.data_model import sizing
+from nbsafety.data_model.annotation_utils import get_type_annotation, make_annotation_string
+from nbsafety.data_model.code_cell import ExecutedCodeCell, cells
 from nbsafety.data_model.timestamp import Timestamp
 from nbsafety.data_model.update_protocol import UpdateProtocol
+from nbsafety.extra_builtins import EMIT_EVENT
+from nbsafety.run_mode import FlowOrder
 from nbsafety.singletons import nbs, tracer
 
 if TYPE_CHECKING:
@@ -79,8 +83,8 @@ class DataSymbol:
         self.containing_scope = containing_scope
         self.stmt_node = self.update_stmt_node(stmt_node)
         self._funcall_live_symbols = None
-        self.parents: Set[DataSymbol] = set()
-        self.children: Set[DataSymbol] = set()
+        self.parents: Dict[DataSymbol, List[Timestamp]] = defaultdict(list)
+        self.children: Dict[DataSymbol, List[Timestamp]] = defaultdict(list)
 
         self.call_scope: Optional[Scope] = None
         if self.is_function:
@@ -92,7 +96,7 @@ class DataSymbol:
         self._timestamp: Timestamp = Timestamp.uninitialized()
         # The version is a simple counter not associated with cells that is bumped whenever the timestamp is updated
         self._version: int = 0
-        self._defined_cell_num = nbs().cell_counter()
+        self._defined_cell_num = cells().exec_counter()
 
         # The necessary last-updated timestamp / cell counter for this symbol to not be stale
         self.required_timestamp: Timestamp = self.timestamp
@@ -100,11 +104,19 @@ class DataSymbol:
         # for each usage of this dsym, the version that was used, if different from the timestamp of usage
         self.timestamp_by_used_time: Dict[Timestamp, Timestamp] = {}
         # History of definitions at time of liveness
-        self.timestamp_by_liveness_time_by_cell_counter: Dict[int, Dict[Timestamp, Timestamp]] = defaultdict(dict)
+        self.timestamp_by_liveness_time: Dict[Timestamp, Timestamp] = {}
         # All timestamps associated with this symbol
         self.updated_timestamps: Set[Timestamp] = set()
 
         self.fresher_ancestors: Set[DataSymbol] = set()
+        self.fresher_ancestor_timestamps: Set[Timestamp] = set()
+
+        # cells where this symbol was live
+        self.cells_where_deep_live: Set[ExecutedCodeCell] = set()
+        self.cells_where_shallow_live: Set[ExecutedCodeCell] = set()
+
+        self._last_computed_staleness_cache_ts: int = -1
+        self._is_stale_at_position_cache: Dict[int, bool] = {}
 
         # if implicitly created when tracing non-store-context ast nodes
         self._implicit = implicit
@@ -122,6 +134,10 @@ class DataSymbol:
                 # acceptable for the use case of improving readable names
                 ns.scope_name = self.name
 
+    @property
+    def cells_where_live(self) -> Set[ExecutedCodeCell]:
+        return self.cells_where_deep_live | self.cells_where_shallow_live
+
     def __repr__(self) -> str:
         return f'<{self.readable_name}>'
 
@@ -339,7 +355,10 @@ class DataSymbol:
         self._tombstone = False
         self._cached_out_of_sync = True
         if nbs().settings.mark_typecheck_failures_unsafe and self.cached_obj_type != type(obj):
-            nbs().cell_counters_needing_typecheck |= nbs().cell_counter_by_live_symbol.get(self, set())
+            for cell in self.cells_where_live:
+                cell.invalidate_typecheck_result()
+        self.cells_where_shallow_live.clear()
+        self.cells_where_deep_live.clear()
         self.obj = obj
         if self.cached_obj_id is not None and self.cached_obj_id != self.obj_id:
             new_ns = nbs().namespaces.get(self.obj_id, None)
@@ -496,6 +515,46 @@ class DataSymbol:
             return False
         return self.timestamp < self.required_timestamp or len(self.namespace_stale_symbols) > 0
 
+    def _is_stale_at_position_impl(self, pos: int) -> bool:
+        for par, timestamps in self.parents.items():
+            for ts in timestamps:
+                dep_introduced_pos = cells().from_timestamp(ts).position
+                if dep_introduced_pos > pos:
+                    continue
+                for updated_ts in par.updated_timestamps:
+                    if cells().from_timestamp(updated_ts).position > dep_introduced_pos:
+                        continue
+                    if updated_ts.cell_num > ts.cell_num or par.is_stale_at_position(ts.cell_num):
+                        # logger.error("sym: %s", self)
+                        # logger.error("pos: %s", pos)
+                        # logger.error("parent: %s", par)
+                        # logger.error("dep introdced ts: %s", ts)
+                        # logger.error("dep introdced pos: %s", dep_introduced_pos)
+                        # logger.error("par updated ts: %s", updated_ts)
+                        # logger.error("par updated position: %s", cells().from_timestamp(updated_ts).position)
+                        return True
+        for sym in self.namespace_stale_symbols:
+            if sym.is_stale_at_position(pos):
+                return True
+        return False
+
+    def is_stale_at_position(self, pos: int) -> bool:
+        assert not hasattr(builtins, EMIT_EVENT), 'this should be called outside of tracing / execution context'
+        if not self.is_stale:
+            return False
+        if nbs().mut_settings.flow_order == FlowOrder.ANY_ORDER:
+            return True
+        if cells().exec_counter() > self._last_computed_staleness_cache_ts:
+            self._is_stale_at_position_cache.clear()
+            self._last_computed_staleness_cache_ts = cells().exec_counter()
+        if pos in self._is_stale_at_position_cache:
+            return self._is_stale_at_position_cache[pos]
+        is_stale = self._is_stale_at_position_impl(pos)
+        self._is_stale_at_position_cache[pos] = is_stale
+        return is_stale
+
+
+
     def should_mark_stale(self, updated_dep):
         if self.disable_warnings:
             return False
@@ -540,16 +599,18 @@ class DataSymbol:
         logger.warning("symbol %s new deps %s", self, new_deps)
         new_deps.discard(self)
         if overwrite:
-            for parent in self.parents - new_deps:
-                parent.children.discard(self)
+            for parent in self.parents.keys() - new_deps:
+                parent.children.pop(self, None)
             self.parents.clear()
 
-        for new_parent in new_deps - self.parents:
+        for new_parent in new_deps - self.parents.keys():
             if new_parent is None:
                 continue
-            new_parent.children.add(self)
-            self.parents.add(new_parent)
+            new_parent.children[self].append(Timestamp.current())
+            self.parents[new_parent].append(Timestamp.current())
         self.required_timestamp = Timestamp.uninitialized()
+        self.fresher_ancestors.clear()
+        self.fresher_ancestor_timestamps.clear()
         if mutated or isinstance(self.stmt_node, ast.AugAssign):
             self.update_usage_info()
         equal_to_old = not mutated and self.prev_obj_definitely_equal_to_current_obj(prev_obj)
@@ -590,13 +651,17 @@ class DataSymbol:
         seen: Set[DataSymbol] = None,
     ) -> None:
         self._temp_disable_warnings = False
-        self.fresher_ancestors.clear()
         if bump_version:
             self._timestamp = Timestamp.current() if timestamp is None else timestamp
+            for cell in self.cells_where_live:
+                cell.add_used_cell_counter(self, self._timestamp.cell_num)
             ns = self.containing_namespace
             if ns is not None:
                 # logger.error("bump version of %s due to %s (value %s)", ns.full_path, self.full_path, self.obj)
                 ns.max_descendent_timestamp = self._timestamp
+                for alias in nbs().aliases[ns.obj_id]:
+                    for cell in alias.cells_where_deep_live:
+                        cell.add_used_cell_counter(alias, self._timestamp.cell_num)
             self.updated_timestamps.add(self._timestamp)
             self._version += 1
         if refresh_descendent_namespaces:
