@@ -6,9 +6,10 @@ import logging
 import shlex
 from typing import cast, TYPE_CHECKING
 
+from nbsafety.data_model.code_cell import cells
 from nbsafety.data_model.data_symbol import DataSymbol
-from nbsafety.ipython_utils import cell_counter, CellNotRunYetError
-from nbsafety.run_mode import ExecutionMode
+from nbsafety.data_model.timestamp import Timestamp
+from nbsafety.run_mode import FlowOrder, ExecutionMode
 from nbsafety.singletons import nbs
 from nbsafety.tracing.symbol_resolver import resolve_rval_symbols
 
@@ -150,12 +151,12 @@ def make_slice(line: str) -> Optional[str]:
         return None
     cell_num = args.cell_num
     if cell_num is None:
-        cell_num = cell_counter() - 1
+        cell_num = cells().exec_counter() - 1
     try:
-        deps = list(nbs().compute_slice(cell_num, stmt_level=args.stmt).items())
+        deps = list(cells().from_timestamp(cell_num).compute_slice(stmt_level=args.stmt).items())
         deps.sort()
         return '\n\n'.join(f'# Cell {cell_num}\n' + content for cell_num, content in deps)
-    except CellNotRunYetError:
+    except KeyError:
         logger.warning("Cell %d has not yet been run", cell_num)
     return None
 
@@ -183,8 +184,8 @@ def remove_dep(line_: str) -> None:
     if parent_data_sym not in child_data_sym.parents:
         logger.warning('The two symbols do not have a dependency relation')
         return
-    parent_data_sym.children.remove(child_data_sym)
-    child_data_sym.parents.remove(parent_data_sym)
+    del parent_data_sym.children[child_data_sym]
+    del child_data_sym.parents[parent_data_sym]
 
 
 def add_dep(line_: str) -> None:
@@ -200,8 +201,8 @@ def add_dep(line_: str) -> None:
     if parent_data_sym in child_data_sym.parents:
         logger.warning('The two symbols already have a dependency relation')
         return
-    parent_data_sym.children.add(child_data_sym)
-    child_data_sym.parents.add(parent_data_sym)
+    parent_data_sym.children[child_data_sym].append(Timestamp.current())
+    child_data_sym.parents[parent_data_sym].append(Timestamp.current())
 
 
 def turn_off_warnings_for(line_: str) -> None:
@@ -242,3 +243,16 @@ def set_exec_mode(line_: str) -> None:
         logger.warning(usage)
         return
     nbs().mut_settings.exec_mode = exec_mode
+
+
+def set_flow_order(line_: str) -> None:
+    line_ = line_.lower().strip()
+    usage = f'Usage: %safety flow [{FlowOrder.ANY_ORDER}|{FlowOrder.IN_ORDER}]'
+    if line_.startswith('any') or line_ in ('unordered', 'both'):
+        flow_order = FlowOrder.ANY_ORDER
+    elif line_.startswith('in') or line_ in ('ordered', 'linear'):
+        flow_order = FlowOrder.IN_ORDER
+    else:
+        logger.warning(usage)
+        return
+    nbs().mut_settings.flow_order = flow_order
