@@ -18,3 +18,8 @@ class SafetyRunMode(Enum):
 class ExecutionMode(Enum):
     NORMAL = 'normal'
     REACTIVE = 'reactive'
+
+
+class FlowOrder(Enum):
+    ANY_ORDER = 'any_order'
+    IN_ORDER = 'in_order'
