@@ -6,7 +6,8 @@ from typing import cast, TYPE_CHECKING
 import sys
 
 from nbsafety.analysis.attr_symbols import resolve_slice_to_constant
-from nbsafety.tracing.trace_events import TraceEvent, EMIT_EVENT
+from nbsafety.extra_builtins import EMIT_EVENT
+from nbsafety.tracing.trace_events import TraceEvent
 from nbsafety.utils import fast
 
 if TYPE_CHECKING:
@@ -102,7 +103,7 @@ class AstEavesdropper(ast.NodeTransformer):
                     func=self._emitter_ast(),
                     args=[
                         TraceEvent.subscript_slice.to_ast(),
-                        self._get_copy_id_ast(node.slice),
+                        self._get_copy_id_ast(node),
                     ],
                     keywords=fast.kwargs(ret=cast(ast.expr, slc)),
                 )
