@@ -4,9 +4,6 @@ from enum import Enum
 from nbsafety.utils import fast
 
 
-EMIT_EVENT = '_X5ix_NBSAFETY_EVT_EMIT'
-
-
 class TraceEvent(Enum):
     init_cell = 'init_cell'
 
@@ -14,6 +11,8 @@ class TraceEvent(Enum):
     after_stmt = 'after_stmt'
     after_module_stmt = 'after_module_stmt'
 
+    after_loop_iter = 'after_loop_iter'
+
     attribute = 'attribute'
     subscript = 'subscript'
     subscript_slice = 'subscript_slice'
