@@ -2,6 +2,7 @@
 import functools
 import logging
 
+from nbsafety.data_model.code_cell import cells
 from nbsafety.singletons import nbs
 from test.utils import make_safety_fixture
 
@@ -44,8 +45,16 @@ def run_cell(cell):
     run_cell_(cell)
 
 
+def compute_slice_stmts(cell_num):
+    return cells().from_timestamp(cell_num).compute_slice_stmts()
+
+
+def compute_slice(cell_num):
+    return cells().from_timestamp(cell_num).compute_slice()
+
+
 def num_stmts_in_slice(cell_num: int) -> int:
-    return sum(len(stmts) for stmts in nbs().compute_slice_stmts(cell_num).values())
+    return sum(len(stmts) for stmts in compute_slice_stmts(cell_num).values())
 
 
 def test_simple():
@@ -53,7 +62,7 @@ def test_simple():
     run_cell('b = 2')
     run_cell('logging.info(a)')
     run_cell('c = a + b')
-    deps = set(nbs().compute_slice(4).keys())
+    deps = set(compute_slice(4).keys())
     assert deps == {1, 2, 4}, 'got %s' % deps
 
 
@@ -69,7 +78,7 @@ def foo():
     return Foo()
 """)
     run_cell('logging.info(foo().foo())')
-    deps = set(nbs().compute_slice(4).keys())
+    deps = set(compute_slice(4).keys())
     assert deps == {1, 2, 3, 4}, 'got %s' % deps
     slice_size = num_stmts_in_slice(4)
     assert slice_size == 4, 'got %d' % slice_size
@@ -79,7 +88,7 @@ def test_nested_symbol_usage():
     run_cell('lst = [1, 2, 3, 4, 5]')
     run_cell('lst[1] = 3')
     run_cell('logging.info(lst[1])')
-    deps = set(nbs().compute_slice(3).keys())
+    deps = set(compute_slice(3).keys())
     assert deps == {1, 2, 3}, 'got %s' % deps
     slice_size = num_stmts_in_slice(3)
     assert slice_size == 3, 'got %d' % slice_size
@@ -96,7 +105,7 @@ def test_nested_symbol_usage_with_variable_subscript():
             run_cell('lst = [1, 2, 3, 4, 5]')
             run_cell('lst[x] = 3')
             run_cell('logging.info(lst[1])')
-            deps = set(nbs().compute_slice(4).keys())
+            deps = set(compute_slice(4).keys())
             assert deps == {1, 2, 3, 4}, 'got %s' % deps
             slice_size = num_stmts_in_slice(4)
             assert slice_size == 4, 'got %d' % slice_size
@@ -115,7 +124,7 @@ else:
 """)
     run_cell('z = 42')
     run_cell('logging.info(x + 1)')
-    deps = set(nbs().compute_slice(3).keys())
+    deps = set(compute_slice(3).keys())
     assert deps == {1, 3}, 'got %s' % deps
     slice_size = num_stmts_in_slice(3)
     assert slice_size == 2, 'got %d' % slice_size
@@ -128,7 +137,7 @@ def test_list_mutations():
     run_cell('lst.append(2)')
     run_cell('lst.append(3); lst.append(4)')
     run_cell('logging.info(lst)')
-    deps = set(nbs().compute_slice(5).keys())
+    deps = set(compute_slice(5).keys())
     assert deps == {2, 3, 4, 5}, 'got %s' % deps
     slice_size = num_stmts_in_slice(5)
     assert slice_size == 5, 'got %d' % slice_size
@@ -138,7 +147,7 @@ def test_imports():
     run_cell('import numpy as np')
     run_cell('arr = np.zeros((5,))')
     run_cell('logging.info(arr * 3)')
-    deps = set(nbs().compute_slice(3).keys())
+    deps = set(compute_slice(3).keys())
     assert deps == {1, 2, 3}, 'got %s' % deps
     slice_size = num_stmts_in_slice(3)
     assert slice_size == 3, 'got %d' % slice_size
@@ -150,7 +159,7 @@ def test_handle_stale():
     run_cell('a = 2')
     run_cell('logging.info(b)')
     run_cell('logging.info(b)')
-    deps = set(nbs().compute_slice(4).keys())
+    deps = set(compute_slice(4).keys())
     assert deps == {1, 2, 4}, 'got %s' % deps
     slice_size = num_stmts_in_slice(4)
     assert slice_size == 3, 'got %d' % slice_size
@@ -162,7 +171,7 @@ def test_multiple_versions_captured():
     run_cell('logging.info(x); y = 7')
     run_cell('x = 5')
     run_cell('logging.info(x + y)')
-    deps = set(nbs().compute_slice(4).keys())
+    deps = set(compute_slice(4).keys())
     assert deps == {1, 2, 3, 4}, 'got %s' % deps
     slice_size = num_stmts_in_slice(4)
     assert slice_size == 3, 'got %d' % slice_size
@@ -183,7 +192,7 @@ else:
 """)
     run_cell('x = 5')
     run_cell('logging.info(x + y)')
-    deps = set(nbs().compute_slice(4).keys())
+    deps = set(compute_slice(4).keys())
     assert deps == {1, 2, 3, 4}, 'got %s' % deps
     slice_size = num_stmts_in_slice(4)
     assert slice_size == 4, 'got %d' % slice_size
@@ -204,7 +213,7 @@ else:
 """)
     run_cell('x = 5')
     run_cell('logging.info(y)')
-    deps = set(nbs().compute_slice(4).keys())
+    deps = set(compute_slice(4).keys())
     assert deps == {1, 2, 4}, 'got %s' % deps
     slice_size = num_stmts_in_slice(4)
     assert slice_size == 3, 'got %d' % slice_size
@@ -214,7 +223,7 @@ def test_parent_usage_includes_child_update():
     run_cell('lst = [3]')
     run_cell('lst[0] += 1')
     run_cell('lst2 = lst + [5]')
-    deps = set(nbs().compute_slice(3).keys())
+    deps = set(compute_slice(3).keys())
     assert deps == {1, 2, 3}, 'got %s' % deps
     slice_size = num_stmts_in_slice(3)
     assert slice_size == 3, 'got %d' % slice_size
@@ -237,7 +246,7 @@ class Foo:
     run_cell("obj.bar()[name]")
     run_cell("something_i_dont_care_about = obj.bar()[name]")
     run_cell("something_i_care_about = obj.bar()[name]")
-    deps = set(nbs().compute_slice(6).keys())
+    deps = set(compute_slice(6).keys())
     assert deps == {1, 2, 3, 6}, 'got %s' % deps
     slice_size = num_stmts_in_slice(6)
     assert slice_size == 4, 'got %d' % slice_size
@@ -278,7 +287,7 @@ class Bar:
     run_cell("x = 1")
     run_cell("the_dictionary = {'something': 1}")
     run_cell("Foo().new(0).foo(1)")
-    deps = set(nbs().compute_slice(5).keys())
+    deps = set(compute_slice(5).keys())
     assert deps == {1, 2, 4, 5}, 'got %s' % deps
     slice_size = num_stmts_in_slice(5)
     assert slice_size == 4, 'got %d' % slice_size
@@ -324,7 +333,7 @@ z = Foo().new(1).bar(0)
 """)
     run_cell("logging.info(z)")
     run_cell("logging.info(y)")
-    deps = set(nbs().compute_slice(6).keys())
+    deps = set(compute_slice(6).keys())
     assert deps == {1, 2, 3, 4, 5, 6}, 'got %s' % deps
     slice_size = num_stmts_in_slice(6)
     assert slice_size == 4, 'got %d' % slice_size
@@ -341,9 +350,9 @@ def test_non_relevant_child_symbol_modified():
     run_cell('lst[0] += 1')
     run_cell('logging.info(lst[1])')
     run_cell('lst[1] = 42')
-    deps = set(nbs().compute_slice(7).keys())
+    deps = set(compute_slice(7).keys())
     assert deps == {1, 4, 7}, 'got %s' % deps
-    deps = set(nbs().compute_slice(8).keys())
+    deps = set(compute_slice(8).keys())
     assert deps == {1, 8}, 'got %s' % deps
     slice_size = num_stmts_in_slice(7)
     assert slice_size == 3, 'got %d' % slice_size
@@ -355,7 +364,7 @@ def test_dynamic_only_increment():
     run_cell('x = 0')
     run_cell('x += 1')
     run_cell('logging.info(x)')
-    deps = set(nbs().compute_slice(3).keys())
+    deps = set(compute_slice(3).keys())
     assert deps == {1, 2, 3}, 'got %s' % deps
     slice_size = num_stmts_in_slice(3)
     assert slice_size == 3, 'got %d' % slice_size
@@ -375,7 +384,7 @@ def test_dynamic_only_variable_subscript():
     run_cell('lst[x] += 1')
     run_cell('x += 1')
     run_cell('logging.info(lst[x])')
-    deps = set(nbs().compute_slice(11).keys())
+    deps = set(compute_slice(11).keys())
     assert deps == {1, 2, 5, 6, 7, 10, 11}, 'got %s' % deps
     slice_size = num_stmts_in_slice(11)
     assert slice_size == len(deps), 'got %d' % slice_size
@@ -393,7 +402,7 @@ try:
     logging.info("%d %d", (1, 2))
 except:
     success = False""")
-    deps = set(nbs().compute_slice(2).keys())
+    deps = set(compute_slice(2).keys())
     assert deps == {2}, 'got %s' % deps
     slice_size = num_stmts_in_slice(2)
     assert slice_size == 1, 'got %d' % slice_size
@@ -406,7 +415,7 @@ def test_list_delete():
     run_cell('del lst[0]')
     run_cell('del lst[2]')
     run_cell('logging.info(lst[1])')
-    deps = set(nbs().compute_slice(5).keys())
+    deps = set(compute_slice(5).keys())
     assert deps == {1, 2, 3, 5}, 'got %s' % deps
     slice_size = num_stmts_in_slice(5)
     assert slice_size == len(deps), 'got %d' % slice_size
