@@ -52,7 +52,7 @@ def test_simple():
         3: 'x = 42',
     }
     run_all_cells(cells)
-    response = nbs().check_and_link_multiple_cells(cells)
+    response = nbs().check_and_link_multiple_cells()
     assert response.stale_cells == {2}
     assert response.fresh_cells == {1}
     assert response.stale_links == {2: {1}}
@@ -68,7 +68,7 @@ def test_refresh_after_exception_fixed():
     run_cell(cells[0], 0)
     run_cell(cells[2], 2, ignore_exceptions=True)
     run_cell(cells[1], 1)
-    response = nbs().check_and_link_multiple_cells(cells)
+    response = nbs().check_and_link_multiple_cells()
     assert response.fresh_cells == {2}
 
 
@@ -80,7 +80,7 @@ def test_refresh_after_val_changed():
         3: 'y = 42',
     }
     run_all_cells(cells)
-    response = nbs().check_and_link_multiple_cells(cells)
+    response = nbs().check_and_link_multiple_cells()
     assert response.fresh_cells == {2}
 
 
@@ -93,7 +93,7 @@ def test_inner_mutation_considered_fresh():
         4: 'lst_0.append(42)',
     }
     run_all_cells(cells)
-    response = nbs().check_and_link_multiple_cells(cells)
+    response = nbs().check_and_link_multiple_cells()
     assert response.stale_cells == set()
     assert response.fresh_cells == {2, 3}
 
@@ -126,32 +126,32 @@ for foo in lst:
 
     run_all_cells(cells)
 
-    response = nbs().check_and_link_multiple_cells(cells)
+    response = nbs().check_and_link_multiple_cells()
     assert response.stale_cells == set()
     assert response.fresh_cells == set(), 'got %s' % response.fresh_cells
 
     cells[4] = 'x.inc()'
     run_cell(cells[4], 4)
 
-    response = nbs().check_and_link_multiple_cells(cells)
+    response = nbs().check_and_link_multiple_cells()
     assert response.stale_cells == set(), 'got %s' % response.stale_cells
     assert response.fresh_cells == {2, 3}, 'got %s' % response.fresh_cells
 
     cells[5] = 'foo.inc()'
     run_cell(cells[5], 5)
-    response = nbs().check_and_link_multiple_cells(cells)
+    response = nbs().check_and_link_multiple_cells()
     assert response.stale_cells == set(), 'got %s' % response.stale_cells
     assert response.fresh_cells == {2, 3, 4}, 'got %s' % response.fresh_cells
 
     if force_subscript_symbol_creation:
         cells[6] = 'lst[-1]'
         run_cell(cells[6], 6)
-        response = nbs().check_and_link_multiple_cells(cells)
+        response = nbs().check_and_link_multiple_cells()
         assert response.stale_cells == set()
         assert response.fresh_cells == {2, 3, 4}
 
     run_cell(cells[4], 4)
-    response = nbs().check_and_link_multiple_cells(cells)
+    response = nbs().check_and_link_multiple_cells()
     assert response.stale_cells == set()
     assert response.fresh_cells == set([2, 3, 5] + ([6] if force_subscript_symbol_creation else []))
 
@@ -163,7 +163,7 @@ def test_no_freshness_for_alias_assignment_post_mutation():
         2: 'x.append(5)',
     }
     run_all_cells(cells)
-    response = nbs().check_and_link_multiple_cells(cells)
+    response = nbs().check_and_link_multiple_cells()
     assert response.stale_cells == set()
     assert response.fresh_cells == set()
 
@@ -174,7 +174,7 @@ def test_fresh_after_import():
         1: 'import numpy as np'
     }
     run_all_cells(cells, ignore_exceptions=True)
-    response = nbs().check_and_link_multiple_cells(cells)
+    response = nbs().check_and_link_multiple_cells()
     assert response.stale_cells == set()
     assert response.fresh_cells == {0}
 
@@ -191,7 +191,7 @@ def test_external_object_update_propagates_to_stale_namespace_symbols():
     }
     with override_settings(mark_stale_symbol_usages_unsafe=False):
         run_all_cells(cells)
-        response = nbs().check_and_link_multiple_cells(cells)
+        response = nbs().check_and_link_multiple_cells()
         assert response.stale_cells == set(), 'got %s' % response.stale_cells
         assert response.fresh_cells == {2, 4}
 
@@ -204,7 +204,7 @@ def test_symbol_on_both_sides_of_assignment():
         3: 'x = 42',
     }
     run_all_cells(cells)
-    response = nbs().check_and_link_multiple_cells(cells)
+    response = nbs().check_and_link_multiple_cells()
     assert response.stale_cells == {2}
     assert response.fresh_cells == {1}
     assert list(response.refresher_links.keys()) == [1]
@@ -218,20 +218,20 @@ def test_updated_namespace_after_subscript_dep_removed():
         3: 'x = 9',
     }
     run_all_cells(cells)
-    response = nbs().check_and_link_multiple_cells(cells)
+    response = nbs().check_and_link_multiple_cells()
     assert response.stale_cells == {2}
     assert response.fresh_cells == {1}
     cells[1] = 'd = {5: 6}'
     run_cell(cells[1], 1)
-    response = nbs().check_and_link_multiple_cells(cells)
+    response = nbs().check_and_link_multiple_cells()
     assert response.stale_cells == set()
     assert response.fresh_cells == {2}
     run_cell(cells[2], 2)
-    response = nbs().check_and_link_multiple_cells(cells)
+    response = nbs().check_and_link_multiple_cells()
     assert response.stale_cells == set()
     assert response.fresh_cells == set()
     run_cell(cells[0], 0)
-    response = nbs().check_and_link_multiple_cells(cells)
+    response = nbs().check_and_link_multiple_cells()
     assert response.stale_cells == set()
     assert response.fresh_cells == set(), 'got %s' % response.fresh_cells
 
@@ -244,11 +244,11 @@ def test_equal_list_update_does_induce_fresh_cell():
         3: 'y = list("".join(y))',
     }
     run_all_cells(cells)
-    response = nbs().check_and_link_multiple_cells(cells)
+    response = nbs().check_and_link_multiple_cells()
     assert response.stale_cells == set()
     assert response.fresh_cells == {2}
     run_cell('y = ("f",)', 4)
-    response = nbs().check_and_link_multiple_cells(cells)
+    response = nbs().check_and_link_multiple_cells()
     assert response.stale_cells == set()
     assert response.fresh_cells == {2, 3}
 
@@ -261,11 +261,11 @@ def test_equal_list_update_does_induce_fresh_cell_LITERAL_WITH_F_IS_REUSED_ON_UB
         3: 'y = list("".join(y))',
     }
     run_all_cells(cells)
-    response = nbs().check_and_link_multiple_cells(cells)
+    response = nbs().check_and_link_multiple_cells()
     assert response.stale_cells == set()
     assert response.fresh_cells == {2}
     run_cell('y = ["f"]', 4)
-    response = nbs().check_and_link_multiple_cells(cells)
+    response = nbs().check_and_link_multiple_cells()
     assert response.stale_cells == set()
     assert response.fresh_cells == {2, 3}
 
@@ -278,11 +278,11 @@ def test_equal_dict_update_does_induce_fresh_cell():
         3: 'y = dict(y.items())',
     }
     run_all_cells(cells)
-    response = nbs().check_and_link_multiple_cells(cells)
+    response = nbs().check_and_link_multiple_cells()
     assert response.stale_cells == set()
     assert response.fresh_cells == {2}, 'got %s' % response.fresh_cells
     run_cell('y = {"foo": 99}', 4)
-    response = nbs().check_and_link_multiple_cells(cells)
+    response = nbs().check_and_link_multiple_cells()
     assert response.stale_cells == set()
     assert response.fresh_cells == {2, 3}
 
@@ -295,11 +295,11 @@ def test_list_append():
         3: 'lst.append(2)',
     }
     run_all_cells(cells)
-    response = nbs().check_and_link_multiple_cells(cells)
+    response = nbs().check_and_link_multiple_cells()
     assert response.stale_cells == set()
     assert response.fresh_cells == set()
     run_cell('lst[1] += 42', 4)
-    response = nbs().check_and_link_multiple_cells(cells)
+    response = nbs().check_and_link_multiple_cells()
     assert response.stale_cells == {2}
     assert response.fresh_cells == {1}
 
@@ -312,11 +312,11 @@ def test_list_extend():
         3: 'lst.extend([2, 3, 4])',
     }
     run_all_cells(cells)
-    response = nbs().check_and_link_multiple_cells(cells)
+    response = nbs().check_and_link_multiple_cells()
     assert response.stale_cells == set()
     assert response.fresh_cells == set()
     run_cell('lst[1] += 42', 4)
-    response = nbs().check_and_link_multiple_cells(cells)
+    response = nbs().check_and_link_multiple_cells()
     assert response.stale_cells == {2}
     assert response.fresh_cells == {1}
 
@@ -328,7 +328,7 @@ def test_implicit_subscript_symbol_does_not_bump_ts():
         2: 'logging.info(lst[0])',
     }
     run_all_cells(cells)
-    response = nbs().check_and_link_multiple_cells(cells)
+    response = nbs().check_and_link_multiple_cells()
     assert response.stale_cells == set()
     assert response.fresh_cells == set()
 
@@ -340,11 +340,11 @@ def test_liveness_skipped_for_simple_assignment_involving_aliases():
         2: 'lst.append(4)',
     }
     run_all_cells(cells)
-    response = nbs().check_and_link_multiple_cells(cells)
+    response = nbs().check_and_link_multiple_cells()
     assert response.stale_cells == set()
     assert response.fresh_cells == set()
     run_cell('lst = [1, 2, 3, 4]', 3)
-    response = nbs().check_and_link_multiple_cells(cells)
+    response = nbs().check_and_link_multiple_cells()
     assert response.stale_cells == set()
     assert response.fresh_cells == {1, 2}, 'got %s' % response.fresh_cells
 
@@ -358,7 +358,7 @@ def test_incorrect_object_not_used_for_argument_symbols():
         3: 'f(np.arange(10))',
     }
     run_all_cells(cells)
-    response = nbs().check_and_link_multiple_cells(cells)
+    response = nbs().check_and_link_multiple_cells()
     assert response.stale_cells == set()
     assert response.fresh_cells == set(), 'got %s' % response.fresh_cells
 
@@ -370,11 +370,11 @@ def test_increment_by_same_amount():
         2: 'logging.info(y)',
     }
     run_all_cells(cells)
-    response = nbs().check_and_link_multiple_cells(cells)
+    response = nbs().check_and_link_multiple_cells()
     assert response.stale_cells == set()
     assert response.fresh_cells == set()
     run_cell('x = 3', 0)
-    response = nbs().check_and_link_multiple_cells(cells)
+    response = nbs().check_and_link_multiple_cells()
     assert response.stale_cells == {2}
     assert response.fresh_cells == {1}
 
@@ -393,7 +393,7 @@ def test_list_insert():
         9: 'lst.insert(3, 3)',
     }
     run_all_cells(cells)
-    response = nbs().check_and_link_multiple_cells(cells)
+    response = nbs().check_and_link_multiple_cells()
     assert response.stale_cells == {8}, 'got %s' % response.stale_cells
     assert response.fresh_cells == {4, 5, 6, 7}, 'got %s' % response.fresh_cells
 
@@ -414,7 +414,7 @@ def _test_list_delete_helper(last_cell):
         11: last_cell,
     }
     run_all_cells(cells)
-    response = nbs().check_and_link_multiple_cells(cells)
+    response = nbs().check_and_link_multiple_cells()
     assert response.stale_cells == {10}
     # TODO: ideally we would detect that lst[3] is the same after deleting
     #  and not consider cell 4 to be fresh
@@ -442,11 +442,11 @@ def test_list_clear():
         2: 'logging.info(lst)',
     }
     run_all_cells(cells)
-    response = nbs().check_and_link_multiple_cells(cells)
+    response = nbs().check_and_link_multiple_cells()
     assert response.stale_cells == set()
     assert response.fresh_cells == set()
     run_cell('lst.clear()', 3)
-    response = nbs().check_and_link_multiple_cells(cells)
+    response = nbs().check_and_link_multiple_cells()
     assert response.stale_cells == set()
     assert response.fresh_cells == {2}
 
@@ -458,11 +458,11 @@ def test_dict_clear():
         2: 'logging.info(d)',
     }
     run_all_cells(cells)
-    response = nbs().check_and_link_multiple_cells(cells)
+    response = nbs().check_and_link_multiple_cells()
     assert response.stale_cells == set()
     assert response.fresh_cells == set()
     run_cell('d.clear()', 3)
-    response = nbs().check_and_link_multiple_cells(cells)
+    response = nbs().check_and_link_multiple_cells()
     assert response.stale_cells == set()
     assert response.fresh_cells == {2}
 
@@ -475,10 +475,10 @@ def test_adhoc_pandas_series_update():
         3: 'df.foo.dropna(inplace=True)',
     }
     run_all_cells(cells)
-    response = nbs().check_and_link_multiple_cells(cells)
+    response = nbs().check_and_link_multiple_cells()
     assert response.stale_cells == set()
     assert response.fresh_cells == set()
     run_cell('df["foo"] = [8, 9]', 4)
-    response = nbs().check_and_link_multiple_cells(cells)
+    response = nbs().check_and_link_multiple_cells()
     assert response.stale_cells == set()
     assert response.fresh_cells == {3}
